==> mediawiki-1.15.1.tgz: mediawiki/languages/messages/MessagesXh.php <==
<?php
/** Xhosa (isiXhosa)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jcwf
 * @author Jose77
 */

$messages = array(
# Dates
'sunday'        => 'Icawe',
'monday'        => 'UMvulo',
'tuesday'       => 'ULwesibini',
'wednesday'     => 'ULwesithathu',
'thursday'      => 'ULwesine',
'friday'        => 'ULwesihlanu',
'saturday'      => 'UMgqibelo',
'january'       => 'EyoMqungu',
'february'      => 'EyoMdumba',
'march'         => 'EyoKwindla',
'april'         => 'EkaTshazimpuzi',
'june'          => 'EyeSilimela',
'july'          => 'EyeKhala',
'august'        => 'EyeThupha',
'september'     => 'Eyo Msintsi',
'october'       => 'Eye Dwarha',
'november'      => 'Eye Nkanga',
'december'      => 'Eyo Mnga',
'january-gen'   => 'EyoMqungu',
'february-gen'  => 'Eyo Mdumba',
'march-gen'     => 'Eyo Kwindla',
'april-gen'     => 'Ekatshazimpuzi',
'may-gen'       => 'EkaCanzibe',
'june-gen'      => 'Eyesilimela',
'july-gen'      => 'Eye Khala',
'august-gen'    => 'Eye Thupha',
'september-gen' => 'Eyo Msintsi',
'october-gen'   => 'Eye Dwarha',
'november-gen'  => 'Eye Nkanga',
'december-gen'  => 'Eyo Mnga',
'may'           => 'EkaCanzibe',

'article'        => 'Inqaku',
'qbspecialpages' => 'Amaphepha Abalulekileyo',
'mypage'         => 'Inqaku yam',
'mytalk'         => 'Inthetho yam',

'help'             => 'Uncedo',
'search'           => 'Khangela',
'searchbutton'     => 'Khangela',
'go'               => 'Hamba',
'searcharticle'    => 'Hamba',
'edit'             => 'Tshintsha',
'delete'           => 'Cima',
'protect'          => 'Khusela',
'talkpagelinktext' => 'Inthetho',
'talk'             => 'Ingxoxo',
'otherlanguages'   => 'Kwezinye Ilwimi',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Imisebenzi Eyenzekayo',
'edithelp'             => 'Uncedo ngoTshintsho',
'mainpage'             => 'Iphepha Elingundoqo',
'mainpage-description' => 'Iphepha Elingundoqo',

'newmessageslink'         => 'imiyalezo emitsha',
'youhavenewmessagesmulti' => 'Unemiyalezo emitsha ku $1',
'editsection'             => 'tshintsha',
'editold'                 => 'tshintsha',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Inqaba',

# General errors
'viewsource' => 'Jonga i Source',

# Login and logout pages
'welcomecreation'    => '== Wamkelekile, $1! ==

I Account yakhgo ivuliwe, ungalibali ukutshitsha izinto ozithandayo ngo {{SITENAME}}.',
'yourname'           => 'Igama lelungu:',
'yourpassword'       => 'Igama elifihlakeleyo lelungu:',
'yourpasswordagain'  => 'Faka kwakhona igama elifihlakeleyo:',
'remembermypassword' => 'Khumbula igama lam elifihlakeleyo kule Khompyutha',
'createaccount'      => 'Vula I Account',
'username'           => 'Igama lelungu:',
'loginlanguagelabel' => 'Ulwimi: $1',

# Edit pages
'summary'     => 'Isishwankathelo:',
'minoredit'   => 'Lutshitsho oluncinci olu',
'watchthis'   => 'Bukela le Page',
'savearticle' => 'Gcina eliphepha',
'showpreview' => 'Bonisa Utshintsho',
'showdiff'    => 'Gcina Utshitshi',

# Search results
'powersearch' => 'Khangela',

# Preferences page
'mypreferences'     => 'Ezithandwa ndim',
'searchresultshead' => 'Khangela',

# Recent changes
'recentchanges'   => 'Utshitsho olusandokwenziwa',
'minoreditletter' => 'nc',

# Recent changes linked
'recentchangeslinked' => 'Utsitsho olufana nolu',

# Upload
'upload'          => 'Faka Ifile',
'filedesc'        => 'Isishwankathelo',
'watchthisupload' => 'Bukela le Page',

# Miscellaneous special pages
'move'         => 'Dlulisa',
'movethispage' => 'Dlulisa eliphepha',

# Special:AllPages
'allinnamespace' => 'Amanqaku onke ($1 namespace)',
'allpagessubmit' => 'Hamba',

# Watchlist
'watchlist'     => 'Endizibukeleyo',
'mywatchlist'   => 'Endizibukeleyo',
'watch'         => 'Bukela',
'watchthispage' => 'Bukela le Page',

# Protect
'prot_1movedto2' => '[[$1]] lidluliselwe [[$2]]',

# Contributions
'contributions' => 'Imisebenzi ye lungu',
'mycontris'     => 'Inkxaso yam',

'sp-contributions-submit' => 'Khangela',

# Block/unblock
'ipblocklist-submit' => 'Khangela',

# Move page
'move-page-legend' => 'Dlulisa eliphepha',
'movepagebtn'      => 'DLulisa eliphepha',
'movedto'          => 'Lidluliselwe',
'1movedto2'        => '[[$1]] lidluliselwe [[$2]]',
'movereason'       => 'Isizathu',

# Special:NewFiles
'ilsubmit' => 'Khangela',

# Special:SpecialPages
'specialpages' => 'Amaphepha Abalulekileyo',

);

==> mediawiki-1.18.1.tgz: mediawiki/languages/messages/MessagesXh.php <==
<?php
/** Xhosa (isiXhosa)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jcwf
 * @author Jose77
 */

$messages = array(
# Dates
'sunday'        => 'Icawe',
'monday'        => 'UMvulo',
'tuesday'       => 'ULwesibini',
'wednesday'     => 'ULwesithathu',
'thursday'      => 'ULwesine',
'friday'        => 'ULwesihlanu',
'saturday'      => 'UMgqibelo',
'january'       => 'EyoMqungu',
'february'      => 'EyoMdumba',
'march'         => 'EyoKwindla',
'april'         => 'EkaTshazimpuzi',
'june'          => 'EyeSilimela',
'july'          => 'EyeKhala',
'august'        => 'EyeThupha',
'september'     => 'Eyo Msintsi',
'october'       => 'Eye Dwarha',
'november'      => 'Eye Nkanga',
'december'      => 'Eyo Mnga',
'january-gen'   => 'EyoMqungu',
'february-gen'  => 'Eyo Mdumba',
'march-gen'     => 'Eyo Kwindla',
'april-gen'     => 'Ekatshazimpuzi',
'may-gen'       => 'EkaCanzibe',
'june-gen'      => 'Eyesilimela',
'july-gen'      => 'Eye Khala',
'august-gen'    => 'Eye Thupha',
'september-gen' => 'Eyo Msintsi',
'october-gen'   => 'Eye Dwarha',
'november-gen'  => 'Eye Nkanga',
'december-gen'  => 'Eyo Mnga',
'may'           => 'EkaCanzibe',

'article' => 'Inqaku',
'mypage'  => 'Inqaku yam',
'mytalk'  => 'Inthetho yam',

# Cologne Blue skin
'qbspecialpages' => 'Amaphepha Abalulekileyo',

# Vector skin
'vector-view-edit' => 'Tshintsha',

'help'             => 'Uncedo',
'search'           => 'Khangela',
'searchbutton'     => 'Khangela',
'go'               => 'Hamba',
'searcharticle'    => 'Hamba',
'edit'             => 'Tshintsha',
'delete'           => 'Cima',
'protect'          => 'Khusela',
'talkpagelinktext' => 'Inthetho',
'talk'             => 'Ingxoxo',
'otherlanguages'   => 'Kwezinye Ilwimi',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Imisebenzi Eyenzekayo',
'edithelp'             => 'Uncedo ngoTshintsho',
'mainpage'             => 'Iphepha Elingundoqo',
'mainpage-description' => 'Iphepha Elingundoqo',

'newmessageslink'         => 'imiyalezo emitsha',
'youhavenewmessagesmulti' => 'Unemiyalezo emitsha ku $1',
'editsection'             => 'tshintsha',
'editold'                 => 'tshintsha',
'editlink'                => 'tshintsha',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Inqaba',

# General errors
'viewsource' => 'Jonga i Source',

# Login and logout pages
'welcomecreation'    => '== Wamkelekile, $1! ==

I Account yakhgo ivuliwe, ungalibali ukutshitsha izinto ozithandayo ngo {{SITENAME}}.',
'yourname'           => 'Igama lelungu:',
'yourpassword'       => 'Igama elifihlakeleyo lelungu:',
'yourpasswordagain'  => 'Faka kwakhona igama elifihlakeleyo:',
'remembermypassword' => 'Khumbula igama lam elifihlakeleyo kule Khompyutha (for a maximum of $1 {{PLURAL:$1|day|days}})',
'createaccount'      => 'Vula I Account',
'loginlanguagelabel' => 'Ulwimi: $1',

# Edit pages
'summary'     => 'Isishwankathelo:',
'minoredit'   => 'Lutshitsho oluncinci olu',
'watchthis'   => 'Bukela le Page',
'savearticle' => 'Gcina eliphepha',
'showpreview' => 'Bonisa Utshintsho',
'showdiff'    => 'Gcina Utshitshi',

# Search results
'powersearch' => 'Khangela',

# Preferences page
'mypreferences'     => 'Ezithandwa ndim',
'searchresultshead' => 'Khangela',
'username'          => 'Igama lelungu:',

# Recent changes
'recentchanges'   => 'Utshitsho olusandokwenziwa',
'minoreditletter' => 'nc',

# Recent changes linked
'recentchangeslinked'         => 'Utsitsho olufana nolu',
'recentchangeslinked-feed'    => 'Utsitsho olufana nolu',
'recentchangeslinked-toolbox' => 'Utsitsho olufana nolu',

# Upload
'upload'          => 'Faka Ifile',
'filedesc'        => 'Isishwankathelo',
'watchthisupload' => 'Bukela le Page',

# Miscellaneous special pages
'move'         => 'Dlulisa',
'movethispage' => 'Dlulisa eliphepha',

# Special:AllPages
'allinnamespace' => 'Amanqaku onke ($1 namespace)',
'allpagessubmit' => 'Hamba',

# Watchlist
'watchlist'     => 'Endizibukeleyo',
'mywatchlist'   => 'Endizibukeleyo',
'watch'         => 'Bukela',
'watchthispage' => 'Bukela le Page',

# Protect
'prot_1movedto2' => '[[$1]] lidluliselwe [[$2]]',

# Contributions
'contributions' => 'Imisebenzi ye lungu',
'mycontris'     => 'Inkxaso yam',

'sp-contributions-talk'   => 'Inthetho',
'sp-contributions-submit' => 'Khangela',

# Block/unblock
'ipblocklist-submit' => 'Khangela',

# Move page
'move-page-legend' => 'Dlulisa eliphepha',
'movepagebtn'      => 'DLulisa eliphepha',
'movedto'          => 'Lidluliselwe',
'1movedto2'        => '[[$1]] lidluliselwe [[$2]]',
'movereason'       => 'Isizathu',

# Special:NewFiles
'ilsubmit' => 'Khangela',

# Special:SpecialPages
'specialpages' => 'Amaphepha Abalulekileyo',

);
